<?php

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 */

namespace WidgetForEventbriteAPI\Includes;

use WidgetForEventbriteAPI\Admin\Admin;
use WidgetForEventbriteAPI\FrontEnd\FrontEnd;
use WidgetForEventbriteAPI\Admin\Admin_Settings;
use WidgetForEventbriteAPI\Admin\Admin_Setup_Wizard;


/**
 * Class Core
 *
 * @package WidgetForEventbriteAPI\Includes
 */
class Core {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @param \Freemius $freemius Object for freemius.
	 */
	public function __construct( $freemius ) {
		global $wfea_instance_counter;
		$wfea_instance_counter = 0;
		$this->plugin_name     = 'widget-for-eventbrite-api';
		$this->version         = WIDGET_FOR_EVENTBRITE_PLUGIN_VERSION;
		$this->freemius        = $freemius;
		$this->utilities       = new Utilities();

	}

	public function run() {
		$this->set_locale();
		$this->settings_pages();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		if ( $this->freemius->can_use_premium_code__premium_only() ) {
			// batch api call hook
			add_action( 'init', function () {
				add_action( 'wfea_api_call', array( $this, 'api_call__premium_only' ), 10, 1 );
			} );
		}
		// set up options
		$options = get_option( 'widget-for-eventbrite-api-settings' );
		if ( false === $options ) {
			$options =  Admin_Settings::option_defaults( 'widget-for-eventbrite-api-settings' );
			add_option( 'widget-for-eventbrite-api-settings', $options );
		}
		// upgrade options
		if ( $this->freemius->is_free_plan() || ( ! empty( $options ) && is_array( $options ) && ! isset( $options['background_api'] ) ) ) {
			$options['background_api'] = 0;
			update_option( 'widget-for-eventbrite-api-settings', $options );
		}
		if ( ! empty( $options ) && is_array( $options ) && ! isset( $options['key'] ) ) {
			$key = get_option( 'widget-for-eventbrite-api-settings-api' );
			if ( false !== $key ) {
				$options['key'] = $key['key'];
				update_option( 'widget-for-eventbrite-api-settings', $options );
				delete_option( 'widget-for-eventbrite-api-settings-api' );
			}
		}

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the WidgetForEventbriteAPIi18n class in order to set the domain and to register the hook
	 * with WordPress.
	 */
	private function set_locale() {

		add_action( 'init', function () {
			load_plugin_textdomain(
				'widget-for-eventbrite-api',
				false,
				dirname( dirname( plugin_basename( __FILE__ ) ) ) . '/languages/'
			);
		} );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 */
	private function settings_pages() {


		$settings = new Admin_Settings( $this->get_plugin_name(), $this->get_version(), $this->freemius );
		add_action( 'admin_menu', array( $settings, 'settings_setup' ) );
		$options = get_option( 'widget-for-eventbrite-api-settings' );
		if ( empty( $options['key'] ) ) {
			$setup = new Admin_Setup_Wizard( $this->get_plugin_name(), $this->get_version(), $this->freemius );
			add_action( 'admin_menu', array( $setup, 'settings_setup' ) );
		}

	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * Retrieve the version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

	/**
	 *  Defining all actions that occur in the admin area.
	 */
	private function define_admin_hooks() {


		$plugin_admin = new Admin( $this->get_plugin_name(), $this->get_version() );


		add_action( 'admin_enqueue_scripts', array( $plugin_admin, 'enqueue_styles' ) );
		add_action( 'admin_enqueue_scripts', array( $plugin_admin, 'enqueue_scripts' ) );
		add_action( 'admin_notices', array( $plugin_admin, 'display_admin_notice' ) );
		add_action( 'admin_init', array( $plugin_admin, 'set_options' ) );
		add_action( 'wp_ajax_wfea_dismiss_notice', array( $plugin_admin, 'wfea_dismiss_notice' ) );
		add_action( 'widgets_init', array( $plugin_admin, 'register_custom_widgets' ) );
		add_filter( 'site_status_tests', array( $plugin_admin, 'site_status_tests' ) );

		if ( $this->freemius->can_use_premium_code__premium_only() ) {
			// stop action scheduler menu being hidden by some plugins
			add_filter( 'wp_mail_smtp_tasks_admin_hide_as_menu', '__return_false', 999999, 1 );
			add_filter( 'wpforms_tasks_admin_hide_as_menu', '__return_false', 999999, 1 );
			add_filter( 'wfea_eventbrite_cache_expiry', array(
				$plugin_admin,
				'eventbrite_api_cache_expiry_set__premium_only'
			) );
		}

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 */
	private function define_public_hooks() {

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		$plugin_public = new FrontEnd( $this->get_plugin_name(), $this->get_version(), $this->utilities );

		add_action( 'init', array( $plugin_public, 'register_image_size' ) );
		add_filter( 'jetpack_photon_skip_for_url', array( $plugin_public, 'jetpack_photon_skip_for_url' ), 9, 2 );


		add_action( 'wp_enqueue_scripts', array( $plugin_public, 'enqueue_styles' ) );
		add_action( 'wp_enqueue_scripts', array( $plugin_public, 'enqueue_scripts' ) );

		if ( $this->freemius->is__premium_only() ) {
			if ( $this->freemius->can_use_premium_code() ) {

				add_action( 'init', function () {
					$slug = apply_filters( 'wfea_single_event_slug', 'e' );
					add_rewrite_rule( '(.?.+?)/' . $slug . '/.*?-?(\d+)/?$', 'index.php?pagename=$matches[1]&wfea_eb_id=$matches[2]', 'top' );
				} );
				add_filter( 'query_vars', function ( $query_vars ) {
					$query_vars[] = 'wfea_eb_id';

					return $query_vars;
				} );
			}
		}


		add_action( 'init', array( $plugin_public, 'add_shortcode' ) );
		if ( $this->freemius->is__premium_only() ) {
			if ( $this->freemius->can_use_premium_code() ) {
				add_action( 'wp_ajax_wfea_ical_request', array( $plugin_public, 'wfea_download_ics__premium_only' ) );
				add_action( 'wp_ajax_nopriv_wfea_ical_request', array(
					$plugin_public,
					'wfea_download_ics__premium_only'
				) );

				add_action( 'init', array( $plugin_public, 'process_search__premium_only' ) );
			}
		}


	}

	public function api_call__premium_only( $args ) {
		Eventbrite_Manager::$instance->async_api_call__premium_only( $args );
	}


}
