<?php
/**
 * @package TemplateUtilities
 *
 * @copyright (c) 2019.
 * @author            Alan Fuller (support@fullworks)
 * @licence           GPL V3 https://www.gnu.org/licenses/gpl-3.0.en.html
 * @link                  https://fullworks.net
 *
 * This file is part of a Fullworks Plugin.
 *
 *     This plugin is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This plugin is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with   Fullworks Security.  https://www.gnu.org/licenses/gpl-3.0.en.html
 *
 *
 */


namespace WidgetForEventbriteAPI\Includes {


	use DateTime;
	use DateTimeZone;
	use http\Url;

	class Utilities {

		protected static $instance;

		private $modal_setup = false;
		private $modal_id;
		private $modal_elements;
		private $plugin_name;
		/**
		 * @var \Freemius $freemius Object for freemius.
		 */
        private $freemius;

		/**
		 * Utilities constructor.
		 */
		public function __construct() {
			/**
			 * @var \Freemius $wfea_fs Object for freemius.
			 */
            global $wfea_fs;
			$this->plugin_name = 'widget-for-eventbrite-api';
            $this->freemius = $wfea_fs;
		}

		/**
		 * @return Utilities
		 */
		public static function get_instance() {
			if ( null == self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		/**
		 * Get age restriction data - music promoters only
		 *
		 * @param $args template $data->args
		 *
		 * @filter wfea_age_restriction<br>
         *  <em>example<em><br>
         * <pre>add_filter( 'wfea_age_restriction',
         *   function( $output, $age ) {
         *     // your code
         *     return $output;
         *   }
         * );</pre>
		 *
		 * @return false|string  false if no restrictions, otherwise string to display age restriction
		 * @api
		 */
		public function get_age_restriction__premium_only( $args ) {
			if ( ! property_exists( get_post(), 'music_properties' ) ) {
				return false;
			}
			if ( ! isset ( $args['music_show_age_restriction'] ) ) {
				return false;
			}
			$age = get_post()->music_properties->age_restriction;
			if ( 'all_ages' == $age || null == $age ) {
				$output = false;
			} else {
				$output = $args['music_show_age_restriction_label'] . $age;
			}

			return wp_kses_post( apply_filters( 'wfea_age_restriction', $output, $age ) );
		}

		/**
		 * Gets API error messages for logs and system display in human format
		 *
		 * @return string message to display
		 * @internal
		 */
		public function get_api_error_string( $error_string ) {

			do {
				$error_string = $error_string->get_error_message();
			} while ( is_wp_error( $error_string ) );

			if ( is_array( $error_string ) ) {
				$text = json_decode( $error_string['body'] );
				if ( null !== $text ) {
					$error_string = $text->error_description;
				} else {
					if ( isset( $error_string['response'] ) ) {
						$error_string = esc_html__( 'Error code from Eventbrite was' ) . ':' . $error_string['response']['code'] . ' ' .
						                esc_html__( 'Error message' ) . ':' . $error_string['response']['message'];
					}
				}
			}

			return $error_string;
		}

		/**
		 * Get the booknow link
		 *
		 * @param $args template $data->args
		 *
		 * @return Url  link to add to book now buttons
		 * @api
		 */
		public function get_booknow_link( $args ) {
			return $this->format_booknow_link( $args, get_post()->url );

		}

		/**
		 * Add to calendar data fields
		 *
		 * @param $args template $data->args
		 *
		 * @return string html hidden inout with calendar data for forms
		 * @api
		 */
		public function get_calendar_fields__premium_only( $args ) {
			$id          = get_post()->ID;
			$location    = $this->get_location_display__premium_only( $args );
			$description = wp_trim_words( apply_filters( 'eawp_excerpt', get_the_excerpt() ), $this->get_element( 'length', $args ), ' &hellip;' );
			$dtstart     = get_post()->start->utc;
			$dtend       = get_post()->end->utc;
			$summary     = get_the_title();
			$url         = get_post()->url;
			$fields      = '<input type="hidden" id="location-' . esc_attr( $id ) . '" name="location" value="' . esc_attr( $location ) . '">';
			$fields      .= '<input type="hidden" id="description-' . esc_attr( $id ) . '" name="description" value="' . esc_attr( $description ) . '">';
			$fields      .= '<input type="hidden" id="dtstart-' . esc_attr( $id ) . '" name="dtstart" value="' . esc_attr( $dtstart ) . '">';
			$fields      .= '<input type="hidden" id="dtend-' . esc_attr( $id ) . '" name="dtend" value="' . esc_attr( $dtend ) . '">';
			$fields      .= '<input type="hidden" id="summary-' . esc_attr( $id ) . '" name="summary" value="' . esc_attr( $summary ) . '">';
			$fields      .= '<input type="hidden" id="url-' . esc_attr( $id ) . '" name="url" value="' . esc_attr( $url ) . '">';

			return $fields;
		}

		/**
		 * Returns a Call to Action object for use in links
		 * amount of detail varies between free and premium
		 *
		 * @param $args template $data->args
		 *
		 * @return object  containing ->text ->availability_class ->class
		 * @api
		 */
		public function get_cta( $args ) {
			$cta                       = array();
			$type                      = 'available';
			$arg                       = explode( ',', $args['booknow_text'] );
			$cta['text']               = $arg[0];
			$cta['availability_class'] = 'event__available';
			$cta['class']              = ( isset( $arg[1] ) ) ? $arg[1] : 'book-now__link';

			if ( $this->freemius->is__premium_only() ) {
				if ( $this->is_coming_soon__premium_only() ) {
					$cta['availability_class'] = 'event__coming-soon';
					if ( $this->get_element( 'coming_soon_button', $args ) ) {
						$type         = 'coming_soon';
						$arg          = explode( ',', $args['coming_soon_button'] );
						$cta['text']  = $arg[0];
						$cta['class'] = ( isset( $arg[1] ) ) ? $arg[1] : 'coming_soon__link';
					}
				}

				if ( $this->is_postponed__premium_only() ) {
					$cta['availability_class'] = 'event__postponed';
					if ( $this->get_element( 'postponed_button', $args ) ) {
						$type         = 'postponed';
						$arg          = explode( ',', $args['postponed_button'] );
						$cta['text']  = $arg[0];
						$cta['class'] = ( isset( $arg[1] ) ) ? $arg[1] : 'postponed__link';
					}
				}
				if ( $this->is_sales_ended__premium_only() ) {
					$cta['availability_class'] = 'event__sales-ended';
					if ( $this->get_element( 'sales_ended_button', $args ) ) {
						$type         = 'sales_ended';
						$arg          = explode( ',', $args['sales_ended_button'] );
						$cta['text']  = $arg[0];
						$cta['class'] = ( isset( $arg[1] ) ) ? $arg[1] : 'sales_ended__link disabled';
					}
				}

				if ( $this->is_tickets_at_the_door__premium_only() ) {
					$cta['availability_class'] = 'event__ticket-at-the-door';
					if ( $this->get_element( 'tickets_at_the_door_button', $args ) ) {
						$type         = 'ticket_at_the_door';
						$arg          = explode( ',', $args['tickets_at_the_door_button'] );
						$cta['text']  = $arg[0];
						$cta['class'] = ( isset( $arg[1] ) ) ? $arg[1] : 'tickets_at_the_door__link disabled';
					}
				}


				if ( $this->is_sold_out__premium_only() ) {
					$cta['availability_class'] = 'event__sold-out';
					if ( $this->get_element( 'sold_out_button', $args ) ) {
						$type         = 'sold_out';
						$arg          = explode( ',', $args['sold_out_button'] );
						$cta['text']  = $arg[0];
						$cta['class'] = ( isset( $arg[1] ) ) ? $arg[1] : 'sold-out__link disabled';
					}
				}

				if ( $this->is_cancelled__premium_only() ) {
					$cta['availability_class'] = 'event__cancelled';
					if ( $this->get_element( 'canceled_event_button', $args ) ) {
						$type         = 'event_canceled';
						$arg          = explode( ',', $args['canceled_event_button'] );
						$cta['text']  = $arg[0];
						$cta['class'] = ( isset( $arg[1] ) ) ? $arg[1] : 'canceled_event__link disabled';
					}
				}

				if ( 'available' == $type && $this->is_unavailable__premium_only() ) {
					$cta['availability_class'] = 'event__unavailable';
					if ( $this->get_element( 'unavailable_button', $args ) ) {
						$type         = 'unavailable';
						$arg          = explode( ',', $args['unavailable_button'] );
						$cta['text']  = $arg[0];
						$cta['class'] = ( isset( $arg[1] ) ) ? $arg[1] : 'unavailable__link disabled';
					}
				}
			}


			if ( 'completed' == get_post()->status || 'ended' == get_post()->status ) {
				$cta['availability_class'] = 'event__past';
				if ( $this->get_element( 'past_event_button', $args ) ) {
					$type         = 'event_completed';
					$arg          = explode( ',', $args['past_event_button'] );
					$cta['text']  = $arg[0];
					$cta['class'] = ( isset( $arg[1] ) ) ? $arg[1] : 'past_event__link disabled';
				}
			}

			if ( 'started' == get_post()->status ) {
				$cta['availability_class'] = 'event__started';
				if ( $this->get_element( 'started_event_button', $args ) ) {
					$type         = 'event_started';
					$arg          = explode( ',', $args['started_event_button'] );
					$cta['text']  = $arg[0];
					$cta['class'] = ( isset( $arg[1] ) ) ? $arg[1] : 'started_event__link';
				}
			}
			$cta                       = apply_filters( 'wfea_cta', $cta, $type );
			$cta['text']               = wp_kses_post( $cta['text'] );
			$cta['class']              = esc_attr( $cta['class'] );
			$cta['availability_class'] = esc_attr( $cta['availability_class'] );

			return (object) $cta;
		}

		/**
		 * Get door time - music promoters only
         * @filter wfea_door_time<br>
		 *  <em>example<em><br>
		 * <pre>add_filter( 'wfea_door_time',
         *   function( $output, $door_time, $start_time ) {
		 *     // your code
		 *     return $output;
		 *   }
         * );</pre>
		 *
		 * @param $args template $data->args
		 *
		 * @return false|string false if not a music promoter, otherwise door time string
		 * @api
		 */
		public function get_door_time__premium_only( $args ) {
			if ( ! property_exists( get_post(), 'music_properties' ) ) {
				return false;
			}

			$door_time   = '';
			$time_format = apply_filters( 'wfea_door_time_format', get_option( 'time_format' ) );
			$start_time  = esc_html( mysql2date( $time_format, $this->get_event_start()->local ) );
			if ( null == get_post()->music_properties->door_time ) {
				$output = sprintf( $args['music_show_door_no_time_label'], $start_time );
			} else {
				$door_epoch       = mysql2date( 'U', get_post()->music_properties->door_time );
				$dt               = new DateTime( "@$door_epoch" );
				$TimeStr          = $dt->format( 'Y-m-d H:i:s' );
				$TimeZoneNameFrom = "UTC";
				$door_time        = date_create( $TimeStr, new DateTimeZone( $TimeZoneNameFrom ) )
					->setTimezone( new DateTimeZone( $this->get_event_start()->timezone ) )->format( $time_format );
				$output           = sprintf( $args['music_show_door_time_label'], $door_time, $start_time );


			}

			return wp_kses_post( apply_filters( 'wfea_door_time', $output, $door_time, $start_time ) );
		}

		/**
		 * Generic get of element whether in an array or not to avoid templates having to code isset() etc
		 *
		 * @param $key
		 * @param $array
		 *
		 * @return false|mixed value of specified element, false if not in an array
		 * @api
		 */
		public function get_element( $key, $array ) {
			if ( isset( $array [ $key ] ) ) {
				return $array [ $key ];
			}

			return false;
		}

		/**
		 * Get a string suitable for including in a CSS class indicating status and locations to enable for instance styling colour
		 * by status or location
         * @filter wfea_event_classes<br>
		 *  <em>example<em><br>
		 * <pre>add_filter( 'wfea_event_classes',
         *   function( $classes ) {
		 *     // your code
		 *     return $classes;
		 *   }
         * );</pre>
		 * @return string  classes for inclusion in class attribute
		 * @api
		 */
		public function get_event_classes__premium_only() {
			$classes = 'status-' . get_post()->status;
			if ( get_post()->online_event ) {
				$classes .= ' online';
			}
			if ( get_post()->is_free ) {
				$classes .= ' free';
			}
			if ( ( ! empty( get_post()->venue ) ) ) {
				$classes .= ' city-' . preg_replace( '/\W+/', '', strtolower( strip_tags( get_post()->venue->address->city ) ) );
				$classes .= ' region-' . preg_replace( '/\W+/', '', strtolower( strip_tags( get_post()->venue->address->region ) ) );
				$classes .= ' country-' . preg_replace( '/\W+/', '', strtolower( strip_tags( get_post()->venue->address->country ) ) );
			}

			return esc_attr( apply_filters( 'wfea_event_classes', $classes ) );
		}

		/**
		 * Get the URL to an event's public viewing page on eventbrite.com.
		 * @return Url URL for https://eventbrite.com event
         * @param $ext  optional extenstion for url e.g. query args
		 * @api
		 */
		public function get_event_eb_url( $ext = null ) {
			return get_post()->url . $ext;
		}

		/**
		 * Get event end date object
         * @filter wfea_eventbrite_event_end<br>
		 *  <em>example<em><br>
		 * <pre>add_filter( 'wfea_eventbrite_event_end',
         *   function( $enddate ) {
		 *     // your code
		 *     return $enddate;  // Object
		 *   }
         * );</pre>
		 *
		 * @return  Object  Enddate object
		 * @api
		 */
		public function get_event_end() {
			return apply_filters( 'wfea_eventbrite_event_end', get_post()->end );
		}

		/**
		 * Get event start date object
		 * @filter wfea_eventbrite_event_start<br>
		 *  <em>example<em><br>
		 * <pre>add_filter( 'wfea_eventbrite_event_start',
         *   function( $startdate ) {
		 *     // your code
		 *     return $startdate;  // Object
		 *   }
         * );</pre>
		 *
		 * @return  Object StartDate object
		 * @api
		 */
		public function get_event_start() {
			return apply_filters( 'wfea_eventbrite_event_start', get_post()->start );
		}

		/**
		 * Returns formatted time string including start and end
         * @filter wfea_combined_date_time_date_format<br>
		 *  <em>example<em><br>
		 * <pre>add_filter( 'wfea_combined_date_time_date_format',
         *   function( $date_format ) {
		 *     // your code
		 *     return $date_format;  // default get_option( 'date_format' )
         *                           // so changes with site settings
		 *   }
         * );</pre>
		 * @filter wfea_combined_date_time_time_format<br>
		 *  <em>example<em><br>
		 * <pre>add_filter( 'wfea_combined_date_time_time_format',
         *   function( $time_format ) {
		 *     // your code
		 *     return $time_format; // get_option( 'time_format' )
         *                          // so changes with site settings
		 *   }
         * );</pre>
         * @filter wfea_event_time<br>
		 *  <em>example<em><br>
		 * <pre>add_filter( 'wfea_event_time',
         *   function( $event_time, $event_start, $event_end ) {
		 *     // your code
		 *     return $event_time;
		 *   }
         * );</pre>
         *
		 *
		 * @param $args template $data->args
		 *
		 * @return String formatted time
		 * @api
		 */
		function get_event_time( $args = false ) {
			// Collect our formats from the admin.
			$date_format     = apply_filters( 'wfea_combined_date_time_date_format', get_option( 'date_format' ) . ', ' );
			$time_format     = apply_filters( 'wfea_combined_date_time_time_format', get_option( 'time_format' ) );
			$combined_format = $date_format . $time_format;

			if ( false == $args || $args['show_end_time'] ) {
				// Determine if the end time needs the date included (in the case of multi-day events).
				$end_time = ( $this->is_multiday_event() )
					? mysql2date( $combined_format, $this->get_event_end()->local )
					: mysql2date( $time_format, $this->get_event_end()->local );
			} else {
				$end_time = '';
			}

			// Assemble the full event time string.
			$event_time = sprintf(
				_x( '%1$s %3$s %2$s', 'Event date and time. %1$s = start time, %2$s = end time %3$s is a separator', 'eventbrite_api' ),
				esc_html( mysql2date( $combined_format, $this->get_event_start()->local ) ),
				esc_html( $end_time ),
				( empty( $end_time ) ) ? '' : '-'
			);

			return apply_filters( 'wfea_event_time', $event_time, $this->get_event_start(), $this->get_event_end() );
		}

		/**
		 * @deprecated
		 */
		public function get_fb_share_href( $args ) {
			if ( $this->freemius->can_use_premium_code__premium_only()) {
				return $this->get_fb_share_href__premium_only( $args );
			}
            return '';
		}

		/**
		 * Facebook share url
		 *
		 * @param $args template $data-args
		 *
		 * @return Url  Facebook share link
		 * @api
		 */
		public function get_fb_share_href__premium_only( $args ) {
			global $wp;

			return 'https://www.facebook.com/sharer/sharer.php?u=' . urlencode( home_url( $wp->request ) );
		}

		/**
		 * @deprecated
		 */
		public function get_gcal_href( $args ) {
			if ( $this->freemius->can_use_premium_code__premium_only()) {
				return $this->get_gcal_href__premium_only( $args );
			}
            return '';
		}

		/**
		 * Google calendar url
		 *
		 * @param $args template $data-args
		 *
		 * @return Url Google calendar share link
		 * @api
		 */
		public function get_gcal_href__premium_only( $args ) {

			$id          = get_post()->ID;
			$location    = $this->get_location_display__premium_only( $args );
			$description = wp_trim_words( apply_filters( 'eawp_excerpt', get_the_excerpt() ), $this->get_element( 'length', $args ), ' &hellip;' );
			$summary     = get_the_title();
			$url         = get_post()->url;
			$gCalLink    = 'https://calendar.google.com/calendar/render?action=TEMPLATE&text='
			               . rawurlencode( esc_attr( $summary ) )
			               . '&dates=' . gmdate( "Ymd", strtotime( get_post()->start->local ) ) . 'T' . gmdate( "His",
					strtotime( get_post()->start->local ) ) . 'Z'
			               . '/'
			               . ( ( get_post()->end->local ) ? gmdate( "Ymd",
						strtotime( get_post()->end->local ) ) . "T" . gmdate( "His",
						strtotime( get_post()->end->local ) ) . "Z" :
					gmdate( "Ymd", strtotime( get_post()->start->start ) + 60 * 60 * 3 ) . "T" . gmdate( "His",
						strtotime( get_post()->start->local ) + 60 * 60 ) . "Z" )
			               . '&details=' . rawurlencode( $url ) . ' ' . rawurlencode( $description )
			               . '&location=' . rawurlencode( $location )
			               . '&trp=false&sprop=' . rawurlencode( $url )
			               . '&sprop=name:' . rawurlencode( get_bloginfo( 'name' ) );

			return $gCalLink;
		}

		/**
		 * Get location in display format
         * @filter wfea_online_venue_name<br>
		 *  <em>example<em><br>
		 * <pre>add_filter( 'wfea_online_venue_name',
         *   function( $name ) {
		 *     // your code
		 *     return $name;  // Default 'Online'
		 *   }
         * );</pre>
		 *
		 * @param $args display options
		 *
		 * @return string Location display name
		 * @api
		 */
		public function get_location_display__premium_only( $args ) {
			$venue   = get_post()->venue;
			$address = array();
			if ( property_exists( $venue, 'address' ) ) {
				$address = $venue->address;
			}
			$a = ( (array) $address );
			unset( $a['localized_multi_line_address_display'] );
			$a = implode( $a );
			if ( empty( $args['location'] ) ) {
				$args['location'] = 'localized_address_display';
			}
			if ( get_post()->online_event && empty( $a ) ) {
				/**
				 * Filters the venue name when Online event.
				 *
				 * Returning false to this hook is the recommended way to hide the admin bar.
				 * The user's display preference is used for logged in users.
				 *
				 *
				 * @param string  translatable Online.
				 */
				return apply_filters( 'wfea_online_venue_name', esc_html__( 'Online', 'widget-for-eventbrite-api' ) );
			} else if ( property_exists( $address, $args['location'] ) ) {
				return wp_kses_post( $address->{$args['location']} );
			} else if ( property_exists( $venue, $args['location'] ) ) {
				return wp_kses_post( $venue->{$args['location']} );
			} else {

				return esc_html__( 'Error in location field requested - check your shortcode: ' . $args['location'], 'widget-for-eventbrite-api' );
			}
		}

		/**
		 * Get music headliner artist names(s) - music promoters only
		 *
		 * Use in template e.g. $artists = $data->utilities->get_music_headliners__premium_only();
		 * @return string  empty or a string, more than one act separated by ', '
		 * @api
		 */
		public function get_music_headliners__premium_only() {

			return $this->get_music_performers_names__premium_only( 'headliner' );

		}

		/**
		 * Get music artist names(s) - music promoters only
         * @filter wfea_music_performer_names_prefix<br>
		 *  <em>example<em><br>
		 * <pre>add_filter( 'wfea_music_performer_names_prefix',
		 *   function( $prefix) {
		 *     // your code
		 *     return $prefix;  // defaalt blank
		 *   }
		 * );</pre>
         * @filter wfea_music_performer_names_separator<br>
		 *  <em>example<em><br>
		 * <pre>add_filter( 'wfea_music_performer_names_separator',
		 *   function( $separator) {
		 *     // your code
		 *     return $separator;  // default ','
		 *   }
		 * );</pre>
         * @filter wfea_music_performer_names_suffix<br>
		 *  <em>example<em><br>
		 * <pre>add_filter( 'wfea_music_performer_names_suffix',
		 *   function( $suffix) {
		 *     // your code
		 *     return $suffix;  // default blank
		 *   }
		 * );</pre>
		 * @params $type 'support' or 'headliner'
		 * @return string  empty or a string, more than one act separated by ', '
		 * @api
		 */
		public function get_music_performers_names__premium_only( $type ) {
			$performers = $this->get_music_performers__premium_only( $type );
			if ( false == $performers ) {
				return '';
			}
			$names = array();
			foreach ( $performers as $p ) {
				foreach ( $p->artists as $k => $artists ) {
					$names[] = $artists->name;
				}
			}
			$prefix    = apply_filters( 'wfea_music_performer_names_prefix', '' );
			$separator = apply_filters( 'wfea_music_performer_names_separator', ', ' );
			$suffix    = apply_filters( 'wfea_music_performer_names_suffix', '' );

			return $prefix . implode( $separator, $names ) . $suffix;
		}

		/**
		 * Get music supporting artist names(s)
		 *
		 * Use in template e.g. $artists = $data->utilities->get_music_supporters__premium_only();
		 * @return string  empty or a string, more than one act separated by ', '
		 * @api
		 */
		public function get_music_supporters__premium_only() {
			return $this->get_music_performers_names__premium_only( 'support' );
		}

		/**
		 * Default templates will use URL which is modified when targeting a single page
		 * this is for custom templates where part of the page wants to go direct to Evenbrite and part go to single page
		 *
		 * @param $args template $data->args
		 *
		 * @return Url  Eventbrite link unchanged
		 * @api
		 */
		public function get_original_booknow_link( $args ) {
			return $this->format_booknow_link( $args, get_post()->eb_url );

		}

		/**
		 * @deprecated
		 */
		public function get_outlook_cal_href( $args ) {
			if ( $this->freemius->can_use_premium_code__premium_only()) {
				return $this->get_outlook_cal_href__premium_only( $args );
			}
            return '';
		}

		/**
		 * Outlook calendar url
		 *
		 * @param $args templat $data->args
		 *
		 * @return Url Outlook live calendar link
		 * @api
		 */
		public function get_outlook_cal_href__premium_only( $args ) {
//<a href="https://bay02.calendar.live.com/calendar/calendar.aspx?rru=addevent&dtstart=20151119T140000Z&dtend=20151119T160000Z&summary=Summary+of+the+event&location=Location+of+the+event&description=example+text.&allday=false&uid=">add to Outlook calendar</a>
			$location    = $this->get_location_display__premium_only( $args );
			$description = wp_trim_words( apply_filters( 'eawp_excerpt', get_the_excerpt() ), $this->get_element( 'length', $args ), ' &hellip;' );
			$summary     = get_the_title();
			$url         = get_post()->url;
			$href        = 'https://outlook.live.com/calendar/calendar.aspx?rru=addevent&dtstart=' .
			               gmdate( "Ymd", strtotime( get_post()->start->local ) ) . 'T' . gmdate( "His",
					strtotime( get_post()->start->local ) ) . 'Z' .
			               '&dtend=' .
			               ( ( get_post()->end->local ) ? gmdate( "Ymd",
					               strtotime( get_post()->end->local ) ) . "T" . gmdate( "His",
					               strtotime( get_post()->end->local ) ) . "Z" :
				               gmdate( "Ymd", strtotime( get_post()->start->start ) + 60 * 60 * 3 ) . "T" . gmdate( "His",
					               strtotime( get_post()->start->local ) + 60 * 60 ) . "Z" ) .
			               '&summary=' . rawurlencode( esc_attr( $summary ) ) .
			               '&location=' . rawurlencode( esc_attr( $location ) ) .
			               '&description=' . rawurlencode( esc_attr( $description ) ) .
			               '&allday=false&uid=';

			return $href;
		}

		/**
		 * Required in templates if on-site popup is required
         * as it enqueues Eventbrite popup scripts
		 * @return string  the popup class
		 * @api
		 */
		public function get_popup_class__premium_only( $args ) {
			if ( $this->get_element( 'popup', $args ) ) {
				if ( ! wp_doing_ajax() ) {
					wp_enqueue_script( $this->plugin_name . '-eb-script' );
					wp_enqueue_script( $this->plugin_name . '-eb-popup' );
				}

				return 'wfea-popup';
			}

			return '';
		}

		/**
		 * Get 'presented by' text - music promoters only
         * @filter wfea_presented_by<br>
		 *  <em>example<em><br>
		 * <pre>add_filter( 'wfea_presented_by',
		 *   function( $output ) {
		 *     // your code
		 *     return $output;
		 *   }
		 * );</pre>
		 *
		 * @param $args  template $dats->args
		 *
		 * @return false|string  false if not music presenter,otherwise 'presented by' string
		 * @api
		 */
		public function get_presented_by__premium_only( $args ) {
			if ( ! property_exists( get_post(), 'music_properties' ) ) {
				return false;
			}
			if ( empty ( get_post()->music_properties->presented_by ) ) {
				return false;
			}
			$output = $args['music_show_presented_by_label'] . get_post()->music_properties->presented_by;

			return wp_kses_post( apply_filters( 'wfea_presented_by', $output ) );
		}

		/**
		 * Get price in display format
		 *
		 * @param $args template $data->options
		 *
		 * @return false|string
		 * @api
		 */
		public function get_price_display__premium_only() {
			$ext = get_post()->external_ticketing;
			if ( ! empty( $ext ) ) {
				if ( $ext->is_free ) {
					return $this->format_display_price_free__premium_only();
				} else {
					if ( empty( $ext->minimum_ticket_price ) ) {
						return '';

					}

					return $this->format_display_price__premum_only( $ext );

				}

			} elseif ( get_post()->is_free ) {
				return $this->format_display_price_free__premium_only();
			} else {
				if ( empty( get_post()->ticket_availability->minimum_ticket_price ) ) {
					$tickets = get_post()->tickets;
					// check all tickets and if all sold out then sold out, as we can't trust the availablity flag
					foreach ( $tickets as $ticket ) {
						if ( true === $ticket->donation ) {
							return $this->format_display_price_donation__premium_only();
						}
					}

					return '';

				}

				return $this->format_display_price__premum_only( get_post()->ticket_availability );
			}


		}

		/**
		 * Section attributes to be used in templates to take classes / ID/ style overrides
		 *
		 * @param $data options data
		 *
		 * @return string
		 * @api
		 */
		public function get_section_attrs( $data ) {
			return sprintf( '%1$s class="wfea %2$s %3$s %4$s %5$s %6$s"',
				( ! empty( $this->get_element( 'cssid', $data->args ) ) ? 'id="' . esc_attr( $this->get_element( 'cssid', $data->args ) ) . '"' : '' ),
				( ! empty( $this->get_element( 'css_class', $data->args ) ) ? '' . esc_attr( $this->get_element( 'css_class', $data->args ) ) . '' : '' ),
				( ! empty( $this->get_element( 'style', $data->args ) ) ? '' . esc_attr( $this->get_element( 'style', $data->args ) ) . '' : '' ),
				( ! empty( $data->template ) ? '' . esc_attr( $data->template ) . '' : '' ),
				esc_attr( $data->event->layout_class ),
				esc_attr( $data->event->layout_name )
			);
		}

		/**
		 * Get ticket availability text
		 *
		 * @param $args display options
		 *
		 * @filter wfea_availability_display $msg, $total_sold, $event_capacity
		 * @return false|string
		 * @api
		 */
		public function get_ticket_availablity__premium_only( $args ) {

			$tickets        = get_post()->tickets;
			$event_capacity = get_post()->capacity;
			$total_sold     = 0;
			if ( $tickets ) {
				foreach ( $tickets as $ticket ) {
					$total_sold += $ticket->quantity_sold;
				}
			}
			$msg = '';
			if ( $total_sold >= $event_capacity ) {
				$msg = esc_html__( 'Sold Out', 'widget-for-eventbrite-api' );
			} else if ( ( $event_capacity - $total_sold ) > $args['show_availability'] ) {
				$msg = esc_html__( 'Tickets Available', 'widget-for-eventbrite-api' );
			} else {
				$msg = sprintf( esc_html__( '%1$s Tickets Remaining', 'widget-for-eventbrite-api' ), ( $event_capacity - $total_sold ) );
			}

			return wp_kses_post( apply_filters( 'wfea_availability_display', $msg, $total_sold, $event_capacity ) );
		}

		/**
		 * @deprecated
		 */
		public function get_twitter_share_href( $args ) {
			if ( $this->freemius->can_use_premium_code__premium_only()) {
				return $this->get_twitter_share_href__premium_only( $args );
			}
            return '';
		}

		/**
		 * Twitter share url
		 *
		 * @param $args display options
		 *
		 * @return Url
		 * @api
		 */
		public function get_twitter_share_href__premium_only( $args ) {
			global $wp;

			return 'https://twitter.com/intent/tweet?text=' . urlencode( get_the_title() . ' ' . $this->get_event_time( $args ) . ' ' . home_url( $wp->request ) );
		}

		/**
		 * Get the venue display name -if it is online display Online
		 *
		 * @param $args display options
		 *
		 * @return string
		 * @api
		 */
		public function get_venue_name_display__premium_only( $args ) {
			$venue = get_post()->venue;
			$name  = '';
			if ( property_exists( $venue, 'name' ) ) {
				$name = $venue->name;
			}
			if ( get_post()->online_event ) {
				return esc_html__( 'Online', 'widget-for-eventbrite-api' );
			}

			return $name;
		}

		/**
		 * @deprecated
		 */
		public function get_yahoo_href( $args ) {
            if ( $this->freemius->can_use_premium_code__premium_only()) {
	            return $this->get_yahoo_href__premium_only( $args );
            }
            return '';
		}

		/**
		 * Yahoo calendar url
		 *
		 * @param $args display options
		 *
		 * @return Url
		 * @api
		 */
		public function get_yahoo_href__premium_only( $args ) {

			// https://calendar.yahoo.com/?v=60&view=d&type=20&title=Monday+Coffee+Chat&st=20211005T083000Z&dur=0300&desc=For+details%2C+go+here%3A%0Ahttps%3A%2F%2Fwww.eventbrite.co.uk%2Fe%2Fmonday-coffee-chat-tickets-153712946561&in_loc=

			$id          = get_post()->ID;
			$location    = $this->get_location_display__premium_only( $args );
			$description = wp_trim_words( apply_filters( 'eawp_excerpt', get_the_excerpt() ), $this->get_element( 'length', $args ), ' &hellip;' );
			$summary     = get_the_title();
			$et          = '';
			if ( get_post()->end->local ) {
				$et = '&et=' . gmdate( "Ymd",
						strtotime( get_post()->end->local ) ) . "T" . gmdate( "His",
						strtotime( get_post()->end->local ) ) . "Z";
			}
			$url       = get_post()->url;
			$yahoolink = 'https://calendar.yahoo.com/?v=60&view=d&type=20&title='
			             . urlencode( esc_attr( get_post()->post_title ) )
			             . '&st=' . gmdate( "Ymd", strtotime( get_post()->start->local ) ) . 'T' . gmdate( "His",
					strtotime( get_post()->start->local ) ) . 'Z'
			             . $et
			             . '&desc=' . rawurlencode( $url ) . ' ' . rawurlencode( $description )
			             . '&in_loc=' . rawurlencode( $location );

			return $yahoolink;
		}

		/**
		 * Checking if template is in level 1 plan or not
		 *
		 * @return bool
		 * @api
		 */
		public function is_l1__premium_only() {
			if ( $this->freemius->is_plan_or_trial( 'gold' ) ) {
				return true;
			}
			$this->display_upgrade_notice__premium_only();

			return false;
		}

		/**
		 * Checking if template is in level 2 plan or not
		 *
		 * @return bool
		 * @api
		 */
		public function is_l2__premium_only() {
			if ( $this->freemius->is_plan_or_trial( 'platinum' ) ) {
				return true;
			}
			$this->display_upgrade_notice__premium_only();

			return false;
		}

		/**
		 * check if a multiday event
		 * @return bool
		 * @internal
		 */
		public function is_multiday_event() {
			// Set date variables for comparison.
			$start_date = mysql2date( 'Ymd', $this->get_event_start()->local );
			$end_date   = mysql2date( 'Ymd', $this->get_event_end()->local );

			// Return true if they're different, false otherwise.
			return ( $start_date !== $end_date );
		}

		/**
		 * @deprecated
		 */
		public function is_popup_allowed( $args ) {
            if ($this->freemius->can_use_premium_code__premium_only()) {
	            return $this->is_popup_allowed__premium_only( $args );
            }
                return false;
		}

		/**
		 * Popup detection used in cal layouts only
		 * @filter wfea_is_popup_allowed false, $args
		 *
		 * @param $args data options
		 *
		 * @return mixed|void  either  false or the ID of the popup
		 * @api
		 */
		public function is_popup_allowed__premium_only( $args ) {
			if ( ! isset( $args['popup'] ) || ! $args['popup'] ) {
				return apply_filters( 'wfea_is_popup_allowed', false, $args );
			}

			if ( $this->freemius->is__premium_only() ) {
				if ( get_post()->is_externally_ticketed ) {
					$url = get_post()->external_ticketing->external_url;
					if ( false === strpos( $url, 'eventbrite.com' ) ) {
						return apply_filters( 'wfea_is_popup_allowed', false, $args );
					} else {
						// if the external URL is actually eventbrite return the 'external' ED ID
						if ( 1 === preg_match( '#eventbrite\.com\/e\/.+\-(\d+$)#', $url, $matches ) ) {
							if ( isset( $matches[1] ) ) {
								return apply_filters( 'wfea_is_popup_allowed', $matches[1], $args );
							}
						}
					}
				}
				if ( $this->is_sold_out__premium_only() ) {
					return apply_filters( 'wfea_is_popup_allowed', false, $args );
				}
				if ( $this->is_unavailable__premium_only() ) {
					return apply_filters( 'wfea_is_popup_allowed', false, $args );
				}
			}

			return apply_filters( 'wfea_is_popup_allowed', get_post()->ID, $args );
		}


		/**
		 * Outputs the links to enable pagination ( if available ) into templates
		 * note this outputs - rather than returns - html
		 *
		 * @param $args
		 * @param $instance
		 * @param $max_num_pages
		 * @param $position
		 *
		 * @return void
		 * @api
		 */
		public function paginate_links__premium_only(
			$args, $instance, $max_num_pages, $position
		) {
			global $wp;
			if ( ! isset( $args['paginate_position'] ) || 'none' == $args['paginate_position'] ) {
				return;
			}

			$current = 1;
			global $wfea_instance_counter;
			if ( isset( $_GET[ 'wfea_page_no_' . $wfea_instance_counter ] ) ) {
				$current = (int) $_GET[ 'wfea_page_no_' . $wfea_instance_counter ];
			}


			$link_args = array(
				'base'      => home_url( $wp->request ) . '%_%',
				'total'     => $max_num_pages,
				'current'   => $current,
				'format'    => '?wfea_page_no_' . $instance . '=%#%',
				'show_all'  => false,
				'prev_next' => true,
				'prev_text' => esc_html__( '« Previous', 'widget-for-eventbrite-api' ),
				'next_text' => esc_html__( 'Next »', 'widget-for-eventbrite-api' ),
			);

			$link_args = apply_filters( 'wfea_paginate_links_args', $link_args, $args, $instance, $position );
			if ( 'both' == $args['paginate_position'] || $position == $args['paginate_position'] ) {
				echo paginate_links( $link_args );
			}
		}

		/**
		 * @param $id
		 * @param $elements
		 * @param string $action
		 * @param bool $script_tags
		 * @param false $demo
		 *
		 * @deprecated not used in templates as per 5.4.3
		 * Keep as legacy custom templates may use this
		 * removed to templates Sep 2021
		 *
		 */
		public function register_eb_modal_widget__premium_only( $id, $elements, $action = 'wp_footer', $script_tags = true, $demo = false ) {
			add_action(
				$action,
				function () use ( $id, $elements, $script_tags, $demo ) {
					if ( ! $this->modal_setup ) {
						$this->modal_setup = true;
					if ( $script_tags ) {
						?>
                        <script>
							<?php
							}
							?>
                            var wfeaModalCallback = function () {
                                console.log('Order complete!');
                            };

                            function wfeaEBWidget(element, id) {
                                if (document.getElementById(element + id)) {
                                    EBWidgets.createWidget({
                                        // Required
                                        widgetType: 'checkout',
                                        eventId: id,
                                        modal: true,
                                        modalTriggerElementId: element + id,
                                        onOrderComplete: wfeaModalCallback
                                    });
                                }

                            }
							<?php
							if ( $script_tags ) {
							?>
                        </script>
						<?php
					}
					}
				if ( $script_tags ) {
					?>
                    <script>
						<?php
						}
						foreach ( $elements as $element ) {
						if ( $demo ) {   // in the demo we need an action to load scripts so we do this - may be a better way but not found it yet
						?>
                        document.addEventListener('click', function (event) {
                            var notice = document.getElementById("load-popup-alert");
                            if (null != notice) {
                                notice.remove();
                            }
                            wfeaEBWidget("<?php echo $element ?>", "<?php echo $id ?>");
                        })
                        ;
						<?php
						}
						?>
                        document.addEventListener('DOMContentLoaded', function (event) {
                            wfeaEBWidget("<?php echo $element ?>", "<?php echo $id ?>");
                        })
                        ;
						<?php
						}

						if ( $script_tags ) {
						?>
                    </script>
					<?php
				}
				},
				9999
			);

		}

		/**
		 * This function is used when creating a plugin for a custom template
		 *
		 * @link https://github.com/alanef/custom-template-example/blob/master/index.php  for example use
		 *
		 * @param $dir
		 *
		 * @api
		 * @return void
		 */
		public function register_template_dirs( $dir ) {
			add_filter( 'widget-for-eventbrite-api_template_paths', function ( $file_paths ) use ( $dir ) {
				//  put this path as first so it will always override others template parts of the same name
				array_unshift( $file_paths, trailingslashit( $dir ) . 'templates/parts' );
				array_unshift( $file_paths, trailingslashit( $dir ) . 'templates/loops' );
				array_unshift( $file_paths, trailingslashit( $dir ) . 'templates' );

				return $file_paths;
			}, 90 );
		}

		/**
		 * @param $args template $data->args
		 * @param $url
		 *
		 * @return string
		 * @internal
		 */
		private function format_booknow_link( $args, $url ) {
			$ext  = ( $this->get_element( 'tickets', $args ) ) ? '#tickets' : '';
			$link = 'href="' . esc_url( $url ) . $ext . '"';
			if ( $this->freemius->is__premium_only() ) {
				if ( false !== $popup_id = $this->is_popup_allowed__premium_only( $args ) ) {
					$link = 'href="#" onclick="return false"  data-eb-id="' . $popup_id . '"';
				}
			}

			return $link;
		}

		/**
		 * @return bool
		 * @internal
		 */
		private function is_sold_out__premium_only() {
			$tickets = get_post()->tickets;
			// check all tickets and if all sold out then sold out, as we can't trust the availablity flag
			$array_count          = array_count_values( array_column( $tickets, 'on_sale_status' ) );
			$all_tickets_sold_out = false;
			if ( isset( $array_count['SOLD_OUT'] ) ) {
				$all_tickets_sold_out = ( count( $tickets ) == $array_count['SOLD_OUT'] );
			}

			return ( $all_tickets_sold_out );
		}

		/**
		 * @return bool
		 * @internal
		 */
		private function is_unavailable__premium_only() {


			return ( ! get_post()->ticket_availability->has_available_tickets );
		}

		/**
		 * @return bool
		 * @internal
		 */
		private function is_coming_soon__premium_only() {
			if ( 'tickets_not_yet_on_sale' == get_post()->event_sales_status->message_code ) {
				return true;
			}

			return false;
		}

		/**
		 * @return bool
		 * @internal
		 */
		private function is_postponed__premium_only() {
			if ( 'event_postponed' == get_post()->event_sales_status->message_code ) {
				return true;
			}

			return false;
		}

		/**
		 * @return bool
		 * @internal
		 */
		private function is_sales_ended__premium_only() {

			if ( get_post()->is_externally_ticketed ) {
				return false;
			}
			if ( 'tickets_with_sales_ended' == get_post()->event_sales_status->message_code ) {
				return true;
			}

			return false;
		}

		/**
		 * @return bool
		 * @internal
		 */
		private function is_tickets_at_the_door__premium_only() {

			if ( get_post()->is_externally_ticketed ) {
				return false;
			}
			if ( 'tickets_at_the_door' == get_post()->event_sales_status->message_code ) {
				return true;
			}

			return false;
		}

		/**
		 * @return bool
		 * @internal
		 */
		private function is_cancelled__premium_only() {
			if ( 'canceled' == get_post()->status ) {
				return true;
			}
			if ( 'event_cancelled' == get_post()->event_sales_status->message_code ) {
				return true;
			}

			return false;
		}

		/**
		 * Get performer objects - music promoters only
		 *
		 * @return object
		 * @internal
		 */
		private function get_music_performers__premium_only( $type ) {
			$performances = get_post()->performances;
			if ( empty ( $performances ) || 0 === count( $performances ) ) {
				return false;
			}

			return array_filter( $performances, function ( $p ) use ( $type ) {
				return ( $type == $p->performer_role );
			} );
		}

		/**
		 * Formats display price when free
		 * @filter wfea_price_display_free Free
		 * @return string
		 * @internal
		 */
		private function format_display_price_free__premium_only() {
			return wp_kses_post( apply_filters(
				'wfea_price_display_free',
				esc_html__( 'Free', 'widget-for-eventbrite-api' )
			) );
		}

		/**
		 * Formats display price when a price
		 * @filter wfea_price_display $price_display,$prices->minimum_ticket_price->major_value,$prices->maximum_ticket_price->major_value,$prices->minimum_ticket_price->currency
		 * @return string
		 * @internal
		 */
		private function format_display_price__premum_only( $prices ) {

			if ( null === $prices->maximum_ticket_price ) {
				$prices->maximum_ticket_price = $prices->minimum_ticket_price;
			}
			if ( $prices->minimum_ticket_price->value == $prices->maximum_ticket_price->value ) {
				$price_display = sprintf( '%1$s%2$s', $this->get_currency_symbol__premium_only(
					$prices->minimum_ticket_price->currency
				),
					$prices->minimum_ticket_price->major_value
				);
			} else {
				$price_display = sprintf( '%1$s%2$s - %1$s%3$s', $this->get_currency_symbol__premium_only(
					$prices->minimum_ticket_price->currency
				),
					$prices->minimum_ticket_price->major_value,
					$prices->maximum_ticket_price->major_value );
			}

			/**
			 * Filters the formatted display price.
			 *
			 * @param string $price_display formated output price.
			 * @param number minimum_ticket_price lowest ticket price.
			 * @param number maximum_ticket_price higest ticket price.
			 * @param string currency currency code.
			 *
			 */
			return wp_kses_post( apply_filters(
				'wfea_price_display',
				$price_display,
				$prices->minimum_ticket_price->major_value,
				$prices->maximum_ticket_price->major_value,
				$prices->minimum_ticket_price->currency
			) );
		}

		/**
		 * Gets a symbol for currency
		 * @filter wfea_currency_symbol  symbol currency
		 * @return string
		 * @internal
		 */
		private function get_currency_symbol__premium_only( $currency ) {
			$symbols = $this->currency_symbols__premium_only();

			return esc_attr( apply_filters( 'wfea_currency_symbol', $symbols[ $currency ], $currency ) );
		}

		/**
		 * table of currency symbols
		 *
		 * @return string
		 * @internal
		 */
		private function currency_symbols__premium_only() {

			return apply_filters(
				'wfea_currency_symbols',
				array(
					'AED' => '&#x62f;.&#x625;',
					'AFN' => '&#x60b;',
					'ALL' => 'L',
					'AMD' => 'AMD',
					'ANG' => '&fnof;',
					'AOA' => 'Kz',
					'ARS' => '&#36;',
					'AUD' => '&#36;',
					'AWG' => 'Afl.',
					'AZN' => 'AZN',
					'BAM' => 'KM',
					'BBD' => '&#36;',
					'BDT' => '&#2547;&nbsp;',
					'BGN' => '&#1083;&#1074;.',
					'BHD' => '.&#x62f;.&#x628;',
					'BIF' => 'Fr',
					'BMD' => '&#36;',
					'BND' => '&#36;',
					'BOB' => 'Bs.',
					'BRL' => '&#82;&#36;',
					'BSD' => '&#36;',
					'BTC' => '&#3647;',
					'BTN' => 'Nu.',
					'BWP' => 'P',
					'BYR' => 'Br',
					'BYN' => 'Br',
					'BZD' => '&#36;',
					'CAD' => '&#36;',
					'CDF' => 'Fr',
					'CHF' => '&#67;&#72;&#70;',
					'CLP' => '&#36;',
					'CNY' => '&yen;',
					'COP' => '&#36;',
					'CRC' => '&#x20a1;',
					'CUC' => '&#36;',
					'CUP' => '&#36;',
					'CVE' => '&#36;',
					'CZK' => '&#75;&#269;',
					'DJF' => 'Fr',
					'DKK' => 'DKK',
					'DOP' => 'RD&#36;',
					'DZD' => '&#x62f;.&#x62c;',
					'EGP' => 'EGP',
					'ERN' => 'Nfk',
					'ETB' => 'Br',
					'EUR' => '&euro;',
					'FJD' => '&#36;',
					'FKP' => '&pound;',
					'GBP' => '&pound;',
					'GEL' => '&#x20be;',
					'GGP' => '&pound;',
					'GHS' => '&#x20b5;',
					'GIP' => '&pound;',
					'GMD' => 'D',
					'GNF' => 'Fr',
					'GTQ' => 'Q',
					'GYD' => '&#36;',
					'HKD' => '&#36;',
					'HNL' => 'L',
					'HRK' => 'kn',
					'HTG' => 'G',
					'HUF' => '&#70;&#116;',
					'IDR' => 'Rp',
					'ILS' => '&#8362;',
					'IMP' => '&pound;',
					'INR' => '&#8377;',
					'IQD' => '&#x639;.&#x62f;',
					'IRR' => '&#xfdfc;',
					'IRT' => '&#x062A;&#x0648;&#x0645;&#x0627;&#x0646;',
					'ISK' => 'kr.',
					'JEP' => '&pound;',
					'JMD' => '&#36;',
					'JOD' => '&#x62f;.&#x627;',
					'JPY' => '&yen;',
					'KES' => 'KSh',
					'KGS' => '&#x441;&#x43e;&#x43c;',
					'KHR' => '&#x17db;',
					'KMF' => 'Fr',
					'KPW' => '&#x20a9;',
					'KRW' => '&#8361;',
					'KWD' => '&#x62f;.&#x643;',
					'KYD' => '&#36;',
					'KZT' => '&#8376;',
					'LAK' => '&#8365;',
					'LBP' => '&#x644;.&#x644;',
					'LKR' => '&#xdbb;&#xdd4;',
					'LRD' => '&#36;',
					'LSL' => 'L',
					'LYD' => '&#x644;.&#x62f;',
					'MAD' => '&#x62f;.&#x645;.',
					'MDL' => 'MDL',
					'MGA' => 'Ar',
					'MKD' => '&#x434;&#x435;&#x43d;',
					'MMK' => 'Ks',
					'MNT' => '&#x20ae;',
					'MOP' => 'P',
					'MRU' => 'UM',
					'MUR' => '&#x20a8;',
					'MVR' => '.&#x783;',
					'MWK' => 'MK',
					'MXN' => '&#36;',
					'MYR' => '&#82;&#77;',
					'MZN' => 'MT',
					'NAD' => 'N&#36;',
					'NGN' => '&#8358;',
					'NIO' => 'C&#36;',
					'NOK' => '&#107;&#114;',
					'NPR' => '&#8360;',
					'NZD' => '&#36;',
					'OMR' => '&#x631;.&#x639;.',
					'PAB' => 'B/.',
					'PEN' => 'S/',
					'PGK' => 'K',
					'PHP' => '&#8369;',
					'PKR' => '&#8360;',
					'PLN' => '&#122;&#322;',
					'PRB' => '&#x440;.',
					'PYG' => '&#8370;',
					'QAR' => '&#x631;.&#x642;',
					'RMB' => '&yen;',
					'RON' => 'lei',
					'RSD' => '&#1088;&#1089;&#1076;',
					'RUB' => '&#8381;',
					'RWF' => 'Fr',
					'SAR' => '&#x631;.&#x633;',
					'SBD' => '&#36;',
					'SCR' => '&#x20a8;',
					'SDG' => '&#x62c;.&#x633;.',
					'SEK' => '&#107;&#114;',
					'SGD' => '&#36;',
					'SHP' => '&pound;',
					'SLL' => 'Le',
					'SOS' => 'Sh',
					'SRD' => '&#36;',
					'SSP' => '&pound;',
					'STN' => 'Db',
					'SYP' => '&#x644;.&#x633;',
					'SZL' => 'L',
					'THB' => '&#3647;',
					'TJS' => '&#x405;&#x41c;',
					'TMT' => 'm',
					'TND' => '&#x62f;.&#x62a;',
					'TOP' => 'T&#36;',
					'TRY' => '&#8378;',
					'TTD' => '&#36;',
					'TWD' => '&#78;&#84;&#36;',
					'TZS' => 'Sh',
					'UAH' => '&#8372;',
					'UGX' => 'UGX',
					'USD' => '&#36;',
					'UYU' => '&#36;',
					'UZS' => 'UZS',
					'VEF' => 'Bs F',
					'VES' => 'Bs.S',
					'VND' => '&#8363;',
					'VUV' => 'Vt',
					'WST' => 'T',
					'XAF' => 'CFA',
					'XCD' => '&#36;',
					'XOF' => 'CFA',
					'XPF' => 'Fr',
					'YER' => '&#xfdfc;',
					'ZAR' => '&#82;',
					'ZMW' => 'ZK',
				)
			);

		}

		/**
		 * Formats donation price
		 * Filterable:'wfea_price_display_donation'
		 * @return string
		 * @internal
		 */
		private function format_display_price_donation__premium_only() {
			return wp_kses_post( apply_filters(
				'wfea_price_display_donation',
				esc_html__( 'Donation', 'widget-for-eventbrite-api' )
			) );
		}

		/**
		 * Displays notice if template not in right plan
		 * @return void
		 * @internal
		 */
		private function display_upgrade_notice__premium_only() {
			if ( current_user_can( 'manage_options' ) ) {
				?>
                <div class="error">
                    <p><?php esc_html_e( 'Your plan does not include this template', 'widget-for-eventbrite-api' ); ?></p>
                    <p><?php esc_html_e( 'Upgrade your plan for access', 'widget-for-eventbrite-api' ); ?></p>
                    <a target="_blank" href="<? echo esc_url( $this->freemius->get_upgrade_url() ); ?>"
                       class=button"><?php esc_html_e( 'Upgrade Link', 'widget-for-eventbrite-api' ); ?></a>
                </div>
				<?php
			}
		}

		/**
		 * Filter for 'wfea_head_date_format'
		 * @return mixed|void
		 * @internal
		 */
		private function get_head_date_format__premium_only() {
			$locale = get_locale();
			if ( 0 === strpos( $locale, 'en_' ) ) {
				$format = 'M jS';
			} else {
				$format = 'j M';
			}

			return apply_filters( 'wfea_head_date_format', $format );
		}

	}

}


